<template>
  <div :class="{'hidden':hidden}" class="pagination-container">
    <el-pagination
      :background="background"
      :current-page.sync="currentPage"
      :page-size.sync="pageSize"
      :layout="layout"
      :page-sizes="pageSizes"
      :total="total"
      v-bind="$attrs"
      popper-class="select_bottom"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
    />
  </div>
</template>

<script>
import { scrollTo } from '@/utils/scroll-to'

export default {
  name: 'Pagination',
  props: {
    total: {
      required: true,
      type: Number
    },
    page: {
      type: Number,
      default: 1
    },
    limit: {
      type: Number,
      default: 20
    },
    pageSizes: {
      type: Array,
      default() {
        return [10, 20, 50, 100]
      }
    },
    layout: {
      type: String,
      default: 'total, sizes, prev, pager, next, jumper'
    },
    background: {
      type: Boolean,
      default: true
    },
    autoScroll: {
      type: Boolean,
      default: true
    },
    hidden: {
      type: Boolean,
      default: false
    }
  },
  computed: {
    currentPage: {
      get() {
        return this.page
      },
      set(val) {
        this.$emit('update:page', val)
      }
    },
    pageSize: {
      get() {
        return this.limit
      },
      set(val) {
        this.$emit('update:limit', val)
      }
    }
  },
  methods: {
    handleSizeChange(val) {
      this.$emit('pagination', { page: this.currentPage, limit: val })
      if (this.autoScroll) {
        scrollTo(0, 800)
      }
    },
    handleCurrentChange(val) {
      this.$emit('pagination', { page: val, limit: this.pageSize })
      if (this.autoScroll) {
        scrollTo(0, 800)
      }
    }
  }
}
</script>

<style scoped>
.pagination-container {
  background: #f8f8fa;
  padding: 10px 0;
}

.pagination-container.hidden {
  display: none;
}

/*::v-deep .el-pagination__sizes .el-input .el-input__inner:hover{*/
/* border-color: #42b983 ;*/
/*}*/
/*::v-deep .el-pagination__sizes .el-input .el-input__inner:focus{*/
/*  border-color: #42b983;*/
/*}*/

</style>
<style lang="scss">
.select_bottom {
  //z-index: 2008; position: absolute; left: 147px !important; top: 355px !important; margin: 0px;
  //border: 1px solid #55aaff;
  //.el-select-dropdown {
  //
  //}
  //.el-select-dropdown {
  //  background-color: #ffffff;
  //}

  //.el-select-dropdown__item.selected {
  //  color: #42b983;
  //}

  //.el-select-dropdown__item.hover,
  //.el-select-dropdown__item:hover {
  //  background: red;
  //  color: #fff;
  //}
}

.el-pagination button, .el-pagination span:not([class*=suffix]) {
  font-size: 14px;
}

.el-pagination .el-select .el-input .el-input__inner {
  line-height: 34px;
  height: 34px;
}

.el-pagination__jump {
  margin-left: 10px;
  margin-right: 10px;
}

.el-pagination__jump .el-input .el-input__inner{
  line-height: 34px;
  height: 34px;
}
</style>
